package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.system.domain.QyInfoPritn;
import com.ruoyi.system.mapper.QyInfoPritnMapper;
import com.ruoyi.system.service.IQyInfoPritnService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 企业打印列表Service业务层处理
 *
 * @author ruoyi
 * @date 2020-01-10
 */
@Service
public class QyInfoPritnServiceImpl implements IQyInfoPritnService
{
    @Autowired
    private QyInfoPritnMapper qyInfoPritnMapper;

    /**
     * 查询企业打印列表
     *
     * @param id 企业打印列表ID
     * @return 企业打印列表
     */
    @Override
    public QyInfoPritn selectQyInfoPritnById(Long id)
    {
        return qyInfoPritnMapper.selectQyInfoPritnById(id);
    }

    /**
     * 查询企业打印列表
     *
     * @param id 企业打印列表ID
     * @return 企业打印列表
     */
    @Override
    public  QyInfoPritn selectQyInfoPritnByBsid(String bsid)
    {
        return qyInfoPritnMapper.selectQyInfoPritnByBsid(bsid);
    }

    /**
     * 查询企业打印列表列表
     *
     * @param qyInfoPritn 企业打印列表
     * @return 企业打印列表
     */
    @Override
    public List<QyInfoPritn> selectQyInfoPritnList(QyInfoPritn qyInfoPritn)
    {
        return qyInfoPritnMapper.selectQyInfoPritnList(qyInfoPritn);
    }

    /**
     * 查询企业打印列表列表
     *
     * @return 企业打印列表
     */
    @Override
    public List<QyInfoPritn> selectQyInfoPritnC(String card)
    {
        return qyInfoPritnMapper.selectQyInfoPritnC(card);
    }

    /**
     * 新增企业打印列表
     *
     * @param qyInfoPritn 企业打印列表
     * @return 结果
     */
    @Override
    public int insertQyInfoPritn(QyInfoPritn qyInfoPritn)
    {
        return qyInfoPritnMapper.insertQyInfoPritn(qyInfoPritn);
    }

    /**
     * 修改企业打印列表
     *
     * @param qyInfoPritn 企业打印列表
     * @return 结果
     */
    @Override
    public int updateQyInfoPritn(QyInfoPritn qyInfoPritn)
    {
        return qyInfoPritnMapper.updateQyInfoPritn(qyInfoPritn);
    }

    /**
     * 修改企业打印列表
     *
     * @param qyInfoPritn 企业打印列表
     * @return 结果
     */
    @Override
    public int updateQyInfoPritnByBsid(QyInfoPritn qyInfoPritn)
    {
        return qyInfoPritnMapper.updateQyInfoPritnByBsid(qyInfoPritn);
    }

    /**
     * 删除企业打印列表对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteQyInfoPritnByIds(String ids)
    {
        return qyInfoPritnMapper.deleteQyInfoPritnByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除企业打印列表信息
     *
     * @param id 企业打印列表ID
     * @return 结果
     */
    public int deleteQyInfoPritnById(Long id)
    {
        return qyInfoPritnMapper.deleteQyInfoPritnById(id);
    }


    /**
     *  查询zzcode
     * @return 结果
     */
    public String selectMaxZzCode ()
    {
        return qyInfoPritnMapper.selectMaxZzCode();
    }


    /**
     * 查询 是否重复下载
     *
     * @param appNo
     * @return
     */
    @Override
    public String selectByAppNo(String appNo) {
        return qyInfoPritnMapper.selectByAppNo(appNo);
    }


    /**
     * 查询 是否重复下载
     *
     * @param appNo
     * @return
     */
    @Override
    public QyInfoPritn selectBySqh(String appNo) {
        return qyInfoPritnMapper.selectBySqh(appNo);
    }

    /**
     * 查询企业打印列表列表
     *
     * @param qyInfoPritn 企业打印列表
     * @return 企业打印列表
     */
    @Override
    public List<QyInfoPritn> selectQyInfoPritnByIsPrint(QyInfoPritn qyInfoPritn)
    {
        return qyInfoPritnMapper.selectQyInfoPritnByIsPrint(qyInfoPritn);
    }




}
